import React, { createContext, useCallback, useState } from "react";
import { Modal } from "../../components/modal";
export const ModalContext = /*#__PURE__*/createContext({
  isOpen: false,
  open: () => null,
  close: () => null,
  width: 350
});

const ModalContextProvider = ({
  children
}) => {
  const [isOpen, setOpen] = useState(false);
  const [content, setContent] = useState( /*#__PURE__*/React.createElement(React.Fragment, null));
  const [width, setWidth] = useState(350);
  const [title, setTitle] = useState();
  const [isPadding, setPadding] = useState(true);
  const open = useCallback((content, title, width, isPadding = true) => {
    setOpen(true);
    setTitle(title);
    setWidth(width || 350);
    setContent(content);
    setPadding(isPadding);
  }, []);
  const close = useCallback(content => {
    setOpen(false);
  }, []);
  return /*#__PURE__*/React.createElement(ModalContext.Provider, {
    value: {
      isOpen,
      open,
      close,
      width,
      title
    }
  }, /*#__PURE__*/React.createElement(Modal, {
    setOpen: setOpen,
    isOpen: isOpen,
    content: content,
    width: width,
    title: title,
    close: () => setOpen(false),
    isPadding: isPadding
  }), children);
};

export default ModalContextProvider;